from displayio import Group, TileGrid, Bitmap, Palette
from adafruit_display_text import bitmap_label as label
import terminalio
from init_pico_lcd_1_14 import WavesharePicoLCD114
import board
from digitalio import DigitalInOut, Direction, Pull
from adafruit_hid.keyboard import Keyboard
from adafruit_hid.keycode import Keycode
import usb_hid
from adafruit_hid.mouse import Mouse
import time

# Mouse
mouse = Mouse(usb_hid.devices)
shift = 10
wait = 0.5
on = 0
kbd = Keyboard(usb_hid.devices)

# First set some parameters used for shapes and text
BORDER = 5
FONTSCALE = 2
BACKGROUND_COLOR = 0x00FF00  # Bright Green
FOREGROUND_COLOR = 0x0000ff  # Blue
TEXT_COLOR = 0xFFFF00

main_group = Group()

lcd = WavesharePicoLCD114()
display = lcd.display
display.show(main_group)

color_bitmap = Bitmap(display.width, display.height, 1)
color_palette = Palette(1)
color_palette[0] = BACKGROUND_COLOR

bg_sprite = TileGrid(color_bitmap, pixel_shader=color_palette, x=0, y=0)
main_group.append(bg_sprite)

# Zeile 70 loeschen und neu schreiben
def loeschen_neu(text, TEXT_COLOR):
    text_area = label.Label(terminalio.FONT, text=text, color=TEXT_COLOR)
    text_width = text_area.bounding_box[2] * FONTSCALE
    text_group = Group(
        scale=FONTSCALE,
        x=display.width // 2 - text_width // 2,
        y=70
    )
    text_group.append(text_area)
    main_group.append(text_group)
    
# Zeile 110 loeschen und neu schreiben
def buttonwahl(text, TEXT_COLOR):
    text_area = label.Label(terminalio.FONT, text=text, color=TEXT_COLOR)
    text_width = text_area.bounding_box[2] * FONTSCALE
    text_group = Group(
        scale=FONTSCALE,
        x=display.width // 2 - text_width // 2,
        y=110
    )
    text_group.append(text_area)
    main_group.append(text_group)

# Display starten und Titel anzeigen
def display_start(TEXT_COLOR):
    # Draw a smaller inner rectangle and display Label
    inner_bitmap = Bitmap(display.width - BORDER * 2, display.height - BORDER * 2, 1)
    inner_palette = Palette(1)
    inner_palette[0] = FOREGROUND_COLOR
    inner_sprite = TileGrid(inner_bitmap, pixel_shader=inner_palette, x=BORDER, y=BORDER)
    main_group.append(inner_sprite)
    text = "Pico Mouse Jiggler"
    text_area = label.Label(terminalio.FONT, text=text, color=TEXT_COLOR)
    text_width = text_area.bounding_box[2] * FONTSCALE
    text_group = Group(
        scale=FONTSCALE,
        x=display.width // 2 - text_width // 2, y=40)
    text_group.append(text_area)
    main_group.append(text_group)
    text = "Start A Button"
    TEXT_COLOR = 0xFFFF00
    buttonwahl(text,TEXT_COLOR)
    

def anzeige_gestartet(TEXT_COLOR):
    # alte Zeile loeschen
    text = "ist angehalten"
    TEXT_COLOR=0x0000FF
    loeschen_neu(text,TEXT_COLOR)
    # neu Zeile schreiben
    text = "ist gestartet"
    TEXT_COLOR = 0xFFFF00
    loeschen_neu(text,TEXT_COLOR)
    # alte Buttonanzeige loeschen
    text = "Start A Button"
    TEXT_COLOR = 0x0000FF
    buttonwahl(text,TEXT_COLOR)
    # neue Buttonanzeige schreiben
    text = "Stop B Button"
    TEXT_COLOR = 0xFFFF00
    buttonwahl(text,TEXT_COLOR)

def anzeige_gestopt(TEXT_COLOR):
    # alte Zeile loeschen
    text = "ist gestartet"
    TEXT_COLOR = 0x0000FF
    loeschen_neu(text,TEXT_COLOR)
    # neu Zeile schreiben
    text = "ist angehalten"
    TEXT_COLOR = 0xFFFF00
    loeschen_neu(text,TEXT_COLOR)
    # alte Buttonanzeige loeschen
    text = "Stop B Button"
    TEXT_COLOR = 0x0000FF
    buttonwahl(text,TEXT_COLOR)
    # neue Buttonanzeige schreiben
    text = "Start A Button"
    TEXT_COLOR = 0xFFFF00
    buttonwahl(text,TEXT_COLOR)

def jiggle(on):
    print("'Jiggle' läuft.")
    while on == 1:
        for i in range (4):
            if not Key_B.value == True:
                on = 0
                print("'Jiggle' wird angehalten.")
                anzeige_gestopt(TEXT_COLOR)
                time.sleep(2)
                print("'Jiggle' ist deaktiviert.")
                break
            mouse.move(x=shift)
            time.sleep(wait)
            if on == 0:
                break
        for i in range (4):
            if not Key_B.value == True:
                on = 0
                print("'Jiggle' wird angehalten.")
                anzeige_gestopt(TEXT_COLOR)
                time.sleep(2)
                print("'Jiggle' ist deaktiviert.")
                break
            mouse.move(x=-shift)
            time.sleep(wait)
            if on == 0:
                break

# Keys definieren
Key_A = DigitalInOut(board.GP15)
Key_A.direction = Direction.INPUT
Key_A.pull = Pull.UP
Key_B = DigitalInOut(board.GP17)
Key_B.direction = Direction.INPUT
Key_B.pull = Pull.UP
# joystick gedrueckt
Key_CONTROL = DigitalInOut(board.GP3)
Key_CONTROL.direction = Direction.INPUT
Key_CONTROL.pull = Pull.UP

display_start(TEXT_COLOR)

# loop forever so you can see the display
while True:
    if not Key_CONTROL.value == True:
        # PC sperren
        kbd.send(Keycode.WINDOWS, Keycode.L)
    if not Key_A.value == True:
        on = 1
        if on == 1:
            print("'Jiggle' wird gestartet.")
            anzeige_gestartet(TEXT_COLOR)
            time.sleep(0.5)
        jiggle(on)
